@@ -1,5 +1,7 @@
-import itertools
 import functools
+import itertools
+
+from collections import abc
 
 
 @functools.singledispatch
@@ -9,10 +11,15 @@ def merge_definitions(*definitions):
 
 @merge_definitions.register(dict)
 def merge_dicts(*definitions):
-    keys = set(itertools.chain(*(definition.keys() for definition in definitions)))
+    if definitions[-1] is None:
+        return None
+    keys = set(itertools.chain(*(definition.keys() for definition in definitions if definition is not None)))
     result = {}
     for key in keys:
-        result[key] = merge_definitions(*(definition[key] for definition in definitions if key in definition))
+        value = merge_definitions(*(definition[key] for definition in definitions
+                                    if definition is not None and key in definition))
+        if value is not None:
+            result[key] = value
     return result
 
 
@@ -22,7 +29,7 @@ def merge_lists(*definitions):
     named_results = {}
     unmerged_results = []
     for definition in itertools.chain(*definitions):
-        if hasattr(definition, '__getitem__') and 'name' in definition:
+        if isinstance(definition, abc.Mapping) and 'name' in definition:
             name = definition['name']
             if name in named_results:
                 named_results[name].append(definition)
